==> horreum-0.12.1-py3-none-any.whl: horreum/raw_client/api/experiment/run/run_request_builder.py <==
from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from ....models.experiment_result import ExperimentResult

class RunRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /api/experiment/run
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]]) -> None:
        """
        Instantiates a new RunRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/api/experiment/run{?datasetId*}", path_parameters)
    
    async def get(self,request_configuration: Optional[RequestConfiguration] = None) -> Optional[List[ExperimentResult]]:
        """
        Run an experiment for a given dataset and experiment profile
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[List[ExperimentResult]]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from ....models.experiment_result import ExperimentResult

        return await self.request_adapter.send_collection_async(request_info, ExperimentResult, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration] = None) -> RequestInformation:
        """
        Run an experiment for a given dataset and experiment profile
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def with_url(self,raw_url: Optional[str] = None) -> RunRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: RunRequestBuilder
        """
        if not raw_url:
            raise TypeError("raw_url cannot be null.")
        return RunRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class RunRequestBuilderGetQueryParameters():
        """
        Run an experiment for a given dataset and experiment profile
        """
        def get_query_parameter(self,original_name: Optional[str] = None) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if not original_name:
                raise TypeError("original_name cannot be null.")
            if original_name == "dataset_id":
                return "datasetId"
            return original_name
        
        # The dataset to run the experiment on
        dataset_id: Optional[int] = None

==> horreum-0.18-py3-none-any.whl: horreum/raw_client/api/experiment/run/run_request_builder.py <==
from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from ....models.experiment_result import ExperimentResult

class RunRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /api/experiment/run
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new RunRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/api/experiment/run{?datasetId*}", path_parameters)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[RunRequestBuilderGetQueryParameters]] = None) -> Optional[list[ExperimentResult]]:
        """
        Run an experiment for a given dataset and experiment profile
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[list[ExperimentResult]]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from ....models.experiment_result import ExperimentResult

        return await self.request_adapter.send_collection_async(request_info, ExperimentResult, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[RunRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        Run an experiment for a given dataset and experiment profile
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def with_url(self,raw_url: str) -> RunRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: RunRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return RunRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class RunRequestBuilderGetQueryParameters():
        """
        Run an experiment for a given dataset and experiment profile
        """
        def get_query_parameter(self,original_name: str) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if original_name is None:
                raise TypeError("original_name cannot be null.")
            if original_name == "dataset_id":
                return "datasetId"
            return original_name
        
        # The dataset to run the experiment on
        dataset_id: Optional[int] = None

    
    @dataclass
    class RunRequestBuilderGetRequestConfiguration(RequestConfiguration[RunRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
